@@ -24,11 +24,9 @@ import collections
 import six
 import tensorflow as tf
 from tensorflow.python.feature_column import feature_column
-from tensorflow.python.feature_column import feature_column_lib
 from tensorflow.python.framework import ops
 from tensorflow.python.ops import lookup_ops
 from tensorflow.python.ops import string_ops
-from tensorflow.python.ops import weights_broadcast_ops
 from tensorflow.python.util import function_utils
 from tensorflow_estimator.python.estimator import model_fn
 from tensorflow_estimator.python.estimator.canned import metric_keys
@@ -395,8 +393,8 @@ def _get_weights_and_check_match_logits(features,
           key=weight_column, shape=(1,))
     if not isinstance(
         weight_column,
-        (feature_column_lib.NumericColumn, feature_column._NumericColumn)):  # pylint: disable=protected-access
-      raise TypeError('Weight column must be either a string or _NumericColumn.'
+        (tf.compat.v2.__internal__.feature_column.DenseColumn, feature_column._DenseColumn)):  # pylint: disable=protected-access
+      raise TypeError('Weight column must be either a string or _DenseColumn.'
                       ' Given type: {}.'.format(type(weight_column)))
     weights = weight_column._get_dense_tensor(  # pylint: disable=protected-access
         feature_column._LazyBuilder(features))  # pylint: disable=protected-access
@@ -563,7 +561,7 @@ def _indicator_labels_mean(labels, weights=None, name=None):
   with ops.name_scope(name, 'labels_mean', (labels, weights)) as scope:
     labels = tf.cast(labels, name='labels', dtype=tf.dtypes.float32)
     if weights is not None:
-      weights = weights_broadcast_ops.broadcast_weights(weights, labels)
+      weights = tf.compat.v2.__internal__.ops.broadcast_weights(weights, labels)
     return tf.compat.v1.metrics.mean(labels, weights=weights, name=scope)
 
 
@@ -624,7 +622,7 @@ def _predictions_mean(predictions, weights=None, name=None):
     predictions = tf.cast(
         predictions, name='predictions', dtype=tf.dtypes.float32)
     if weights is not None:
-      weights = weights_broadcast_ops.broadcast_weights(weights, predictions)
+      weights = tf.compat.v2.__internal__.ops.broadcast_weights(weights, predictions)
     return tf.compat.v1.metrics.mean(predictions, weights=weights, name=scope)
 
 
@@ -633,7 +631,7 @@ def _auc(labels, predictions, weights=None, curve='ROC', name=None):
     predictions = tf.cast(
         predictions, name='predictions', dtype=tf.dtypes.float32)
     if weights is not None:
-      weights = weights_broadcast_ops.broadcast_weights(weights, predictions)
+      weights = tf.compat.v2.__internal__.ops.broadcast_weights(weights, predictions)
     return tf.compat.v1.metrics.auc(
         labels=labels,
         predictions=predictions,
