@@ -644,8 +644,8 @@ def validate_loss_fn_args(loss_fn):
 
 
 def validate_loss_reduction(loss_reduction):
-  if (loss_reduction not in tf.compat.v2.keras.losses.Reduction.all() or
-      loss_reduction == tf.compat.v2.keras.losses.Reduction.NONE):
+  if (loss_reduction not in tf.losses.Reduction.all() or
+      loss_reduction == tf.losses.Reduction.NONE):
     raise ValueError(
         'Invalid loss_reduction: {}. See `tf.losses.Reduction` for valid '
         'options.'.format(loss_reduction))
@@ -773,12 +773,11 @@ def all_class_ids(logits, n_classes):
 def all_classes(logits, n_classes, label_vocabulary=None):
   batch_size = tf.compat.v1.shape(logits)[0]
   if label_vocabulary:
-    classes_list = label_vocabulary
+    classes_list = tf.convert_to_tensor([label_vocabulary])
   else:
-    classes_list = tf.strings.as_string(tf.range(n_classes))
-  return tf.tile(
-      input=tf.compat.v1.expand_dims(input=classes_list, axis=0),
-      multiples=[batch_size, 1])
+    classes_list = tf.expand_dims(tf.range(n_classes), axis=0)
+    classes_list = tf.strings.as_string(classes_list)
+  return tf.tile(input=classes_list, multiples=[batch_size, 1])
 
 
 def classification_output(scores, n_classes, label_vocabulary=None):
@@ -857,7 +856,7 @@ def create_estimator_spec_train_op(
     train_op_fn=None,
     update_ops=None,
     regularized_training_loss=None,
-    loss_reduction=tf.compat.v2.keras.losses.Reduction.SUM_OVER_BATCH_SIZE):
+    loss_reduction=tf.losses.Reduction.SUM_OVER_BATCH_SIZE):
   """Create train_op for estimator_spec.
 
   Args:
@@ -899,7 +898,7 @@ def create_estimator_spec_train_op(
         validate_v2_optimizer(optimizer)
         validate_trainable_variables(trainable_variables)
         # Scale loss by number of replicas.
-        if loss_reduction == tf.compat.v2.keras.losses.Reduction.SUM_OVER_BATCH_SIZE:
+        if loss_reduction == tf.losses.Reduction.SUM_OVER_BATCH_SIZE:
           num_replicas = tf.distribute.get_strategy().num_replicas_in_sync
           if num_replicas > 1:
             regularized_training_loss *= (1. / num_replicas)
